from ..base import AdyenServiceBase
from .bin_lookup_api import BinLookupApi


class AdyenBinlookupApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super().__init__(client=client)
        self.bin_lookup_api = BinLookupApi(client=client)
