from ..base import AdyenServiceBase
from .session_authentication_api import SessionAuthenticationApi


class AdyenSessionAuthenticationApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super().__init__(client=client)
        self.session_authentication_api = SessionAuthenticationApi(client=client)
