from ..base import AdyenServiceBase
from .balance_control_api import BalanceControlApi


class AdyenBalanceControlApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super().__init__(client=client)
        self.balance_control_api = BalanceControlApi(client=client)
