from ..base import AdyenServiceBase
from .stored_value_api import StoredValueApi


class AdyenStoredValueApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super().__init__(client=client)
        self.stored_value_api = StoredValueApi(client=client)
