from ..base import AdyenServiceBase


class GrantAccountsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super().__init__(client=client)
        self.service = "capital"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/capital/v1"

    def get_grant_account_information(self, id, idempotency_key=None, **kwargs):
        """
        Get the information of your grant account
        """
        endpoint = self.baseUrl + f"/grantAccounts/{id}"
        method = "GET"
        return self.client.call_adyen_api(
            None, self.service, method, endpoint, idempotency_key, **kwargs
        )
